//=========================================================================
//
//	FILE:				CP_Dialog_App.cpp
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Application class for the CP_Dialog demo app.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 4 $
//						Latest Checkout:  $Date: 2005-09-09 22:34:22 -0700 (Fri, 09 Sep 2005) $
//
//=========================================================================

	// CP_Scrolling
#include "CP_Dialog_App.h"

	// CPLAT_Framework
#include "CP_Alerts.h"
#include "CP_Application.tmpl.h"
#include "CP_Dialog.h"
#include "CP_EditField.h"
#include "CP_New.h"
#include "CP_ObjectIDs.h"
#include "CP_PushButton.h"
#include "CP_StaticText.h"
#include "CP_WindowManager.h"
#include "CP_WindowTypes.h"

#if TARGET_CC_METROWERKS
#pragma mark === Construction / Destruction ==
#endif

//=========================================================================
//	FUNCTION:	CP_Dialog_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Constructor.
*	
*	@exception	none
*/
CP_Dialog_Application::CP_Dialog_Application()
{
}

//=========================================================================
//	FUNCTION:	CP_Dialog_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Destructor.
*	
*	@exception	none
*/
CP_Dialog_Application::~CP_Dialog_Application() throw()
{
}

#if TARGET_CC_METROWERKS
#pragma mark === AboutBox ===
#endif

//=========================================================================
//	FUNCTION:	GetAboutBoxDescription
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Return the string that describes the purpose of the application in the
*	AboutBox.
*	
*	@exception	none
*
*	@return		CP_String const		The description, displayed in the about box.
*/
CPLAT::CP_String CP_Dialog_Application::GetAboutBoxDescription() const
{
	CPLAT::CP_String		returnDescription;
	
	returnDescription = "A simple CPLAT application to show simple dialog handling.";
	
	return( returnDescription );
}

#if TARGET_CC_METROWERKS
#pragma mark === Commands ==
#endif

//=========================================================================
//	FUNCTION:	HandleOpenApplication
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Called when the application is starting up. We take this opportunity to
*	create our initial window and views. In this demo, we create a single dialog
*	that has both an edit field and a static text line.
*	
*	@exception	none
*
*	@return		void
*/
void CP_Dialog_Application::HandleOpenApplication()
{
	try
	{
		CPLAT::CP_Point						backWindowLocation;
		
			// create a couple of do-nothing windows to show dialog activation
		backWindowLocation.Set( 50, 100 );
		CreateBackgroundWindow( backWindowLocation );
		backWindowLocation.Set( 100, 150 );
		CreateBackgroundWindow( backWindowLocation );

			// main dialog handling code
		CPLAT::CP_Dialog					*dialog = CP_new CPLAT::CP_Dialog;
		CPLAT::CP_Point						upperLeft( 50, 50 );
		CPLAT::CP_Size						contentSize( 400, 200 );
		CPLAT::CP_String					title( CP_T("Dialog Window") );
		CPLAT::CP_ModalDialogWindowType		dialogWindowType;
		CPLAT::CP_Window					*dialogWindow = NULL;
		CPLAT::CP_String					okButtonTitle( CP_T("OK") );
		CPLAT::CP_String					cancelButtonTitle( CP_T("Cancel") );
		CPLAT::CP_StaticText				*staticText = NULL;
		CPLAT::CP_EditField					*editField = NULL;
		
		dialog->Create( upperLeft, contentSize, title, dialogWindowType );
		dialog->CreateButtons( okButtonTitle, cancelButtonTitle );
		
		dialogWindow = dialog->GetWindow();
		
		CPLAT::CP_DataValueSignal			*dismissSignal = dialog->FindSignal( kCP_Signal_DismissDialog );
		CPLAT::CP_DataValueSignal			*cancelSignal = dialog->FindSignal( kCP_Signal_CancelDialog );

		if( dismissSignal != NULL )
			dismissSignal->connect( CPLAT::CP_SigSlot::slot(this, &CP_Dialog_Application::HandleDismiss) );
			
		if( cancelSignal != NULL )
			cancelSignal->connect( CPLAT::CP_SigSlot::slot(this, &CP_Dialog_Application::HandleCancel) );
		
			// put in a couple of views
		upperLeft.Set( 13, 26 );
		contentSize.Set( 300, 20 );
		title = "This is some static text";
		staticText = CP_new CPLAT::CP_StaticText( dialogWindow, upperLeft, contentSize, title );

		upperLeft.Set( 13, 50 );
		contentSize.Set( 300, 22 );
		title = "This is an edit field";
		editField = CP_new CPLAT::CP_EditField( dialogWindow, upperLeft, contentSize, title, true );

		dialog->Run( CPLAT::CP_Dialog::kCP_DialogModality_Modal );
	}
	catch(...)
	{
	}
}

//=========================================================================
//	FUNCTION:	HandleDismiss
//	
//	VISIBLITY:	Private
//=========================================================================
/*!
*	Slot called when the user clicks on the dismiss button in the dialog.
*
*	@param		inValue					Not used.
*	@param		inOutStatus				Returns the status, in this case CP_noErr
*										to indicate that the close of the dialog
*										can proceed.
*	
*	@exception	none
*
*	@return		void
*/
void CP_Dialog_Application::HandleDismiss( CPLAT::CP_DataValueHolder& /*inValue*/,
	CPLAT::OSStatus& inOutStatus )
{
	CPLAT::CP_String			dialogMessage( CP_T("Dismiss button pressed.") );
	CPLAT::CP_String			noMessage( CP_T("") );
	
	CPLAT::CP_Alerts::CP_OSAlert::ShowAlert( dialogMessage, noMessage );
	
	inOutStatus = CP_noErr;		// so dismissal of dialog proceeds
}

//=========================================================================
//	FUNCTION:	HandleCancel
//	
//	VISIBLITY:	Private
//=========================================================================
/*!
*	Slot called when the user clicks on the cancel button in the dialog.
*
*	@param		inValue					Not used.
*	@param		inOutStatus				Returns the status, in this case CP_noErr
*										to indicate that the close of the dialog
*										can proceed.
*	
*	@exception	none
*
*	@return		void
*/
void CP_Dialog_Application::HandleCancel( CPLAT::CP_DataValueHolder& /*inValue*/,
	CPLAT::OSStatus& inOutStatus )
{
	CPLAT::CP_String			dialogMessage( CP_T("Cancel button pressed.") );
	CPLAT::CP_String			noMessage( CP_T("") );
	
	CPLAT::CP_Alerts::CP_OSAlert::ShowAlert( dialogMessage, noMessage );
	
	inOutStatus = CP_noErr;		// so dismissal of dialog proceeds
}

//=========================================================================
//	FUNCTION:	CreateBackgroundWindow
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Creates a window to place behind the dialog to show dialog handling with
*	other windows.
*
*	@param		inLocation				Location to display the window at.
*	
*	@exception	none
*
*	@return		void
*/
void CP_Dialog_Application::CreateBackgroundWindow( const CPLAT::CP_Point& inLocation )
{
	try
	{
		CPLAT::CP_Point					windowLocation = inLocation;
		CPLAT::CP_Size					windowSize( 250, 150 );
		CPLAT::CP_String				windowTitle( CP_T("Background window") );
		CPLAT::CP_DocumentWindowType	documentWindowType;
		CPLAT::CP_Window				*documentWindow = NULL;
		
		documentWindow = CP_new CPLAT::CP_Window();
		documentWindow->Create( windowLocation, windowSize, windowTitle, documentWindowType );

		CPLAT::CP_MenuBarManager::Instance()->GetCurrentMenuBar()->SetMainWindow( documentWindow );

		documentWindow->Show();
	}
	catch(...)
	{
	}
}

#if TARGET_OS_MAC

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Mac Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_MAC

#if TARGET_OS_WIN32

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Win Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_WIN32

#if TARGET_OS_LINUX

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Linux Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_WIN32
