//=========================================================================
//
//	FILE:				CP_HelloWorld_App.cpp
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Application class for the CP_HelloWorld demo.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 8 $
//						Latest Checkout:  $Date: 2005-09-10 20:29:59 -0700 (Sat, 10 Sep 2005) $
//
//=========================================================================

	// Precompile header support
#include "CP_Precomp.h"

	// CP_HelloWorld;
#include "CP_HelloWorld_App.h"
#include "CP_HelloWorld_View.h"

	// CPLAT_Framework
#include "CP_Application.tmpl.h"
#include "CP_MenuBarManager.h"
#include "CP_Window.h"
#include "CP_WindowManager.h"

#include "CP_DrawerWindow.h"

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Construction / Destruction ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	CP_HelloWorld_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Constructor.
*	
*	@exception	none
*/
CP_HelloWorld_Application::CP_HelloWorld_Application()
{
}

//=========================================================================
//	FUNCTION:	~CP_HelloWorld_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Destructor.
*	
*	@exception	none
*/
CP_HelloWorld_Application::~CP_HelloWorld_Application() throw()
{
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === AboutBox ===
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	GetAboutBoxDescription
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Return the string that describes the purpose of the application in the
*	AboutBox.
*	
*	@exception	none
*
*	@return		CP_String const		The description, displayed in the about box.
*/
CPLAT::CP_String CP_HelloWorld_Application::GetAboutBoxDescription() const
{
	CPLAT::CP_String		returnDescription;
	
	returnDescription = "A simple CPLAT application to display HelloWorld.";
	
	return( returnDescription );
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Commands ===
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	HandleNewCommand
//	
//	VISIBLITY:	Private
//=========================================================================
/*!
*	Override the New command handler to create new windows. Since this application
*	is using a NULL document policy, we don't normally have the New menu item
*	enabled.
*
*	@return		inOutStatus			Return the OSStatus of this operation here.
*	@return		inCommandNo			The command being executed, in this case
*									CP_CMD_New/
*	
*	@exception	none
*
*	@return		void
*/
void CP_HelloWorld_Application::HandleNewCommand( CPLAT::OSStatus& inOutStatus,
	CPLAT::CP_CommandNo& inCommandNo )
{
	CPLAT::OSStatus			status = CP_noErr;
	
	HandleOpenApplication();

	inOutStatus = status;
}

//=========================================================================
//	FUNCTION:	HandleOpenApplication
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Called when the application is starting up. We take this opportunity to
*	create our initial window and views. In this demo, we create a single view,
*	CP_HelloWorld_View that displays our single line of text.
*	
*	@exception	none
*
*	@return		void
*/
void CP_HelloWorld_Application::HandleOpenApplication()
{
	try
	{
		CPLAT::CP_Point					windowLocation( 50, 50 );
		CPLAT::CP_Size					windowSize( 250, 150 );
		CPLAT::CP_String				windowTitle( CP_T("Hello World") );
		CPLAT::CP_DocumentWindowType	documentWindowType;
		
		fWindow = CP_new CPLAT::CP_Window();
		fWindow->Create( windowLocation, windowSize, windowTitle, documentWindowType );

		CPLAT::CP_MenuBarManager::Instance()->GetCurrentMenuBar()->SetMainWindow( fWindow );

		CPLAT::CP_Point					viewLocation( 0, 0 );
		CPLAT::CP_Size					viewSize( 250, 150 );
		CP_HelloWorld_View				*helloWorldView = NULL;

		helloWorldView = CP_new CP_HelloWorld_View( fWindow, viewLocation, viewSize );
		helloWorldView->SetFrameAdapter( CP_new CPLAT::CP_FrameAdapter_Sticky() );

		CPLAT::CP_WindowManager::Instance()->Reposition( fWindow, NULL, CPLAT::kCP_E_WindowPos_WindowCascadeOnMainScreen );

		fWindow->Show();
	}
	catch(...)
	{
	}
}

#if TARGET_OS_MAC

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Mac Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_MAC

#if TARGET_OS_WIN32

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Win Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_WIN32

#if TARGET_OS_LINUX

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Linux Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_LINUX
