//=========================================================================
//
//	FILE:				CP_SignalSlot_App.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Application class for the CP_SignalSlot demo.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 4 $
//						Latest Checkout:  $Date: 2005-08-28 20:40:50 -0700 (Sun, 28 Aug 2005) $
//
//=========================================================================
#ifndef _H_CP_SignalSlot_Application
#define _H_CP_SignalSlot_Application
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Application.h"
#include "CP_DocumentPolicy_None.h"
#include "CP_OSStatus.h"
#include "CP_PrintPolicy_None.h"
#include "CP_SmartPtr.h"
#include "CP_Types.h"
#include "CP_UndoPolicy_None.h"

/*!
*	@class		CP_SignalSlot_Application
*	@brief		Application class for the SignalSlot demo.
*/
class CP_SignalSlot_Application : public CPLAT::CP_Application<CPLAT::CP_DocumentPolicy_None,
		CPLAT::CP_PrintPolicy_None, CPLAT::CP_UndoPolicy_None>
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_SignalSlot_Application();
	//! Destructor.
	virtual								~CP_SignalSlot_Application() throw();
	//@}
			
protected:
	//! @name AboutBox
	//@{
	virtual	CPLAT::CP_String			GetAboutBoxDescription() const;
	//@}

	//! @name Commands
	//@{
	virtual	void						HandleOpenApplication();

										/*!
										*	Handles the menu/command update status handler for the CP_CMD_New command. We
										*	always enable the command, so many windows can be created if desired.
										*	
										*	@param		inOutCommandStatuss		Loccation to return the enabled status result in.
										*	@param		inOutWasHandled			Not used.
										*	@param		inCommandNo				Not used.
										*
										*	@exception	none
										*	
										*	@return		void
										*/
	virtual	void						HandleNewUpdateCommandStatusCommand(
												CPLAT::CP_CommandStatus& inOutCommandStatus,
												bool& /*inOutWasHandled*/,
												CPLAT::CP_CommandNo& /*inCommandNo*/ )					{ inOutCommandStatus.SetIsEnabled( true ); }
	virtual	void 						HandleNewCommand(
												CPLAT::OSStatus& inOutStatus,
												CPLAT::CP_CommandNo& inCommandNo );
	//@}

private:
	typedef CPLAT::CP_Application<CPLAT::CP_DocumentPolicy_None, CPLAT::CP_PrintPolicy_None, CPLAT::CP_UndoPolicy_None>	inherited;

	//! @name Slots
	//@{
			void						ControlClicked(
												CPLAT::CP_DataValueHolder& inValue,
												CPLAT::OSStatus& inOutStatus );
			void						HandleReturn(
												CPLAT::CP_DataValueHolder& inDataValue,
												CPLAT::OSStatus& inOutOSStatus );
	//@}

	// class data
protected:
	CPLAT::CP_Window			*fWindow;		/* ! Main window used to display the SignalSlot View */

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

#endif	// _H_CP_SignalSlot_Application

