//=========================================================================
//
//	FILE:				CP_DT_Resources.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Definitions of various MacOS resource functions that
//						record allocation and deallocation for leak detection.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_DT_Resources
#define _H_CP_DT_Resources
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_MAC

#if CP_Debug_RecordOSCalls

//==========================================================================
//	Resource Manager
//==========================================================================

#define GetResource(theType, theID)						CP_DT_DebugTrap_GetResource( theType, theID, __FUNCTION__, __FILE__, __LINE__ )
#define Get1Resource(theType, theID)					CP_DT_DebugTrap_Get1Resource( theType, theID, __FUNCTION__, __FILE__, __LINE__ )
#define GetIndResource(theType, index)					CP_DT_DebugTrap_GetIndResource( theType, index, __FUNCTION__, __FILE__, __LINE__ )
#define Get1IndResource(theType, index)					CP_DT_DebugTrap_Get1IndResource( theType, index, __FUNCTION__, __FILE__, __LINE__ )
#define GetNamedResource(theType, name)					CP_DT_DebugTrap_GetNamedResource( theType, name, __FUNCTION__, __FILE__, __LINE__ )
#define Get1NamedResource(theType, name)				CP_DT_DebugTrap_Get1NamedResource( theType, name, __FUNCTION__, __FILE__, __LINE__ )
#define LoadResource(theResource)						CP_DT_DebugTrap_LoadResource( theResource, __FUNCTION__, __FILE__, __LINE__ )
#define ReleaseResource(theResource)					CP_DT_DebugTrap_ReleaseResource( theResource )
#define DetachResource(theResource)						CP_DT_DebugTrap_DetachResource( theResource )
#define AddResource(theData, theType, theID, name)		CP_DT_DebugTrap_AddResource( theData, theType, theID, name )
#define	GetResAttrrs(theResource)						CP_DT_DebugTrap_GetResAttrs( theResource )
#define GetResInfo( theResource, theID, theType, name )	CP_DT_DebugTrap_GetResInfo( theResource, theID, theType, name )
#define SetResInfo( theResource, theID, name )			CP_DT_DebugTrap_SetResInfo( theResource, theID, name )
#define ChangedResource(theResource)					CP_DT_DebugTrap_ChangedResource( theResource )
#define RemoveResource(theResource)						CP_DT_DebugTrap_RemoveResource( theResource )
#define WriteResource(theResource)						CP_DT_DebugTrap_WriteResource( theResource )

#if ! TARGET_API_MAC_CARBON
	#define RGetResource( theType, theID )				CP_DT_DebugTrap_RGetResource( theType, theID )
#endif

#define ReadPartialResource( theResource, offset, buffer, count )	CP_DT_DebugTrap_ReadPartialResource( theResource, offset, buffer, count )
#define WritePartialResource( theResource, offset, buffer, count )	CP_DT_DebugTrap_WritePartialResource( theResource, offset, buffer, count )
#define SetResourceSize( theResource, newSize )						CP_DT_DebugTrap_SetResourceSize( theResource, newSize )

pascal Handle 	CP_DT_DebugTrap_GetResource(
						ResType theType,
						SInt16 theID,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal Handle 	CP_DT_DebugTrap_Get1Resource(
						ResType theType,
						SInt16 theID,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal Handle 	CP_DT_DebugTrap_GetIndResource(
						ResType theType,
						SInt16 index,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal Handle 	CP_DT_DebugTrap_Get1IndResource(
						ResType theType,
						SInt16 index,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal Handle 	CP_DT_DebugTrap_GetNamedResource(
						ResType theType,
						ConstStr255Param name,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal Handle 	CP_DT_DebugTrap_Get1NamedResource(
						ResType theType,
						ConstStr255Param name,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal void 	CP_DT_DebugTrap_LoadResource(
						Handle theResource,
						const char *inFunction,
						const char *srcFileName,
						SInt16 srcLineNumber );
pascal void 	CP_DT_DebugTrap_ReleaseResource( Handle theResource );
pascal void 	CP_DT_DebugTrap_DetachResource( Handle theResource );
pascal void 	CP_DT_DebugTrap_AddResource(
						Handle theData,
						ResType theType,
						SInt16 theID,
						ConstStr255Param name );
pascal void 	CP_DT_DebugTrap_GetResAttrs( Handle theResource );
pascal void 	CP_DT_DebugTrap_GetResInfo(
						Handle theResource,
						SInt16 *theID,
						ResType *theType,
						Str255 name );
pascal void 	CP_DT_DebugTrap_SetResInfo(
						Handle theResource,
						SInt16 theID,
						Str255 name );
pascal void 	CP_DT_DebugTrap_ChangedResource( Handle theResource );
pascal void 	CP_DT_DebugTrap_RemoveResource( Handle theResource );
pascal void	 	CP_DT_DebugTrap_WriteResource( Handle theResource );

#if ! TARGET_API_MAC_CARBON
pascal Handle 	CP_DT_DebugTrap_RGetResource(
						ResType theType,
						SInt16 theID );
#endif

pascal void 	CP_DT_DebugTrap_ReadPartialResource(
						Handle theResource,
						long offset,
						void *buffer,
						long count );
pascal void 	CP_DT_DebugTrap_WritePartialResource(
						Handle theResource,
						long offset,
						void *buffer,
						long count );
pascal void 	CP_DT_DebugTrap_SetResourceSize(
						Handle theResource,
						long newSize );

#endif 	// __CP_USE_DEBUG_TRAPS__

#endif	// __BUILD_MAC__

#endif	// _H_CP_DT_Resources

