//=========================================================================
//
//	FILE:				CP_DT_WinObjects.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Memory recording for Window objects.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_DT_WinObjects
#define _H_CP_DT_WinObjects
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Types.h"

#if TARGET_OS_WIN32

		// Windows
#include <windows.h>

CPLAT_Begin_Namespace_CPLAT

#if CP_Debug_RecordOSCalls		// only compile this file if flag defined

	// Bitmap
#define CreateBitmap( width, height, planes, bitsPel, bits )			CP_DT_CreateBitmap( width, height, planes, bitsPel, bits, __FUNCTION__, __FILE__, __LINE__ )
#define CreateBitmapIndirect( bitmap )									CP_DT_CreateBitmapIndirect( bitmap, __FUNCTION__, __FILE__, __LINE__ )
#define CreateCompatibleBitmap( hdc, width, height )					CP_DT_CreateCompatibleBitmap( hdc, width, height, __FUNCTION__, __FILE__, __LINE__ )
#define CreateDiscardableBitmap( hdc, width, height )					CP_DT_CreateDiscardableBitmap( hdc, width, height, __FUNCTION__, __FILE__, __LINE__ )
#define CreateDIBBitmap( hdc, header, inited, data, dim, usage )		CP_DT_CreateDIBBitmap( hdc, header, inited, data, dim, usage, __FUNCTION__, __FILE__, __LINE__ )

	// DC
#define CreateCompatibleDC( hdc )										CP_DT_CreateCompatibleDC( hdc, __FUNCTION__, __FILE__, __LINE__ )
#define DeleteDC( inDC )												CP_DT_DeleteDC( inDC )
//#define GetDC( inHwnd )												CP_DT_GetDC( inHwnd, __FUNCTION__, __FILE__, __LINE__ )
//#define ReleaseDC( inHwnd, inDC )										CP_DT_ReleaseDC( inHwnd, inDC )

	// Pen / Brush
#define CreatePen( flags, width, color )								CP_DT_CreatePen( flags, width, color, __FUNCTION__, __FILE__, __LINE__ )
#define CreatePenIndirect( logpen )										CP_DT_CreatePenIndirect( logpen, __FUNCTION__, __FILE__, __LINE__ )
#define CreateSolidBrush( color )										CP_DT_CreateSolidBrush( color, __FUNCTION__, __FILE__, __LINE__ )
#define CreatePatternBrush( bitmap )									CP_DT_CreatePatternBrush( bitmap, __FUNCTION__, __FILE__, __LINE__ )
#define CreateBrushIndirect( brush )									CP_DT_CreateBrushIndirect( brush, __FUNCTION__, __FILE__, __LINE__ )
#define CreateDIBPatternBrush( dibData, colorSpec )						CP_DT_CreateDIBPatternBrush( dibData, colorSpec, __FUNCTION__, __FILE__, __LINE__ )
#define CreateDIBPatternBrushPt( dibData, colorSpec )					CP_DT_CreateDIBPatternBrushPt( dibData, colorSpec, __FUNCTION__, __FILE__, __LINE__ )

	// GDI Shapes
#define CreateEllipticRgn( left, top, right, bottom )					CP_DT_CreateEllipticRgn( left, top, right, bottom, __FUNCTION__, __FILE__, __LINE__ )
#define CreateEllipticRgnIndirect( rect )								CP_DT_CreateEllipticRgnIndirect( rect, __FUNCTION__, __FILE__, __LINE__ )
#define CreateRectRgn( left, right, top, bottom )						CP_DT_CreateRectRgn( left, right, top, bottom, __FUNCTION__, __FILE__, __LINE__ )
#define CreateRectRgnIndirect( inRect )									CP_DT_CreateRectRgnIndirect( inRect, __FUNCTION__, __FILE__, __LINE__ )
#define CreateRoundRectRgn( left, top, right, bottom, width, height )	CP_DT_CreateRoundRectRgn( left, top, right, bottom, width, height, __FUNCTION__, __FILE__, __LINE__ )

	// Memory
#define GlobalAlloc( flags, bytes )										CP_DT_GlobalAlloc( flags, bytes, __FUNCTION__, __FILE__, __LINE__ )
#define GlobalReAlloc( memory, bytes, flags )							CP_DT_GlobalReAlloc( memory, bytes, flags, __FUNCTION__, __FILE__, __LINE__ )
#define GlobalFree( memory )											CP_DT_GlobalFree( memory )

	// Palettes
#define CreatePalette( inPalette )										CP_DT_CreatePalette( inPalette, __FUNCTION__, __FILE__, __LINE__ )

	// Fonts
#undef CreateFontIndirect
#define CreateFontIndirect( logFont )									CP_DT_CreateFontIndirect( logFont, __FUNCTION__, __FILE__, __LINE__ )

#define DeleteObject( GDIObject )										CP_DT_DeleteObject( GDIObject )

	// Bitmap
HBITMAP							CP_DT_CreateBitmap(
											SInt16 inWidth,
											SInt16 inHeight,
											UInt16 inNumPlanes,
											UInt16 inBitsPerPel,
											const void *bits,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HBITMAP							CP_DT_CreateBitmapIndirect(
											const BITMAP *inBitmap,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HBITMAP							CP_DT_CreateCompatibleBitmap(
											HDC inHDC,
											SInt16 inWidth,
											SInt16 inHeight,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HBITMAP							CP_DT_CreateDiscardableBitmap(
											HDC inHDC,
											SInt16 inWidth,
											SInt16 inHeight,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HBITMAP							CP_DT_CreateDIBBitmap(
											HDC inHDC,
											const BITMAPINFOHEADER *inHeader,
											DWORD inIsInited,
											const void *inBitmapData,
											const BITMAPINFO *inBitmapDim,
											UINT inUsage,
											char *inFunction,
											char *inFile,
											SInt16 inLine );

	// DC
HDC								CP_DT_CreateCompatibleDC(
											HDC inHDC,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
BOOL							CP_DT_DeleteDC( HDC inDC );
HDC								CP_DT_GetDC(
											HWND inHwnd,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
BOOL							CP_DT_ReleaseDC(
											HWND inHwnd,
											HDC inDC );

	// Memory
HGLOBAL							CP_DT_GlobalAlloc(
											UINT inFlags,
											DWORD inBytes,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HGLOBAL							CP_DT_GlobalReAlloc(
											HGLOBAL inMemory,
											DWORD inBytes,
											UINT inFlags,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HGLOBAL							CP_DT_GlobalFree( HGLOBAL inMemory );

	// Pen / Brush
HPEN							CP_DT_CreatePen(
											SInt16 flags,
											SInt16 width,
											COLORREF inColor,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HPEN							CP_DT_CreatePenIndirect(
											const LOGPEN *inLogpen,
											char *srcFileName,
											SInt16 srcLineNumber );
HBRUSH							CP_DT_CreateSolidBrush(
											COLORREF inColor,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HBRUSH							CP_DT_CreatePatternBrush(
											HBITMAP inBitmap,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HBRUSH							CP_DT_CreateBrushIndirect(
											const LOGBRUSH *inBrush,
											char *srcFileName,
											SInt16 srcLineNumber );
HBRUSH							CP_DT_CreateDIBPatternBrush(
											HGLOBAL inDIBData,
											UINT inColorSpec,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HBRUSH							CP_DT_CreateDIBPatternBrushPt(
											const void *inDIBData,
											UINT inColorSpec,
											char *inFunction,
											char *inFile,
											SInt16 inLine );

HPALETTE						CP_DT_CreatePalette(
											const LOGPALETTE *inPalette,
											char *inFunction,
											char *inFile,
											SInt16 inLine );

	// GDI Shapes
HRGN							CP_DT_CreateEllipticRgn(
											int inLeft,
											int inRight,
											int inTop,
											int inBottom,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HRGN							CP_DT_CreateEllipticRgnIndirect(
											const RECT *inRect,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HRGN							CP_DT_CreateRectRgn(
											int inLeft,
											int inRight,
											int inTop,
											int inBottom,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HRGN							CP_DT_CreateRectRgnIndirect(
											const RECT *inRect,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
HRGN							CP_DT_CreateRoundRectRgn(
											int inLeft,
											int inRight,
											int inTop,
											int inBottom,
											int inEllipseWidth,
											int inEllipseHeight,
											char *inFunction,
											char *inFile,
											SInt16 inLine );


	// Fonts
#ifdef UNICODE
HFONT							CP_DT_CreateFontIndirect(
											const LOGFONTW *inLogFont,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
#else
HFONT							CP_DT_CreateFontIndirect(
											const LOGFONTA *inLogFont,
											char *inFunction,
											char *inFile,
											SInt16 inLine );
#endif

	// Deletion
BOOL							CP_DT_DeleteObject( HGDIOBJ inGDIObject );

#endif	// CP_Debug_RecordOSCalls		// only compile this file if flag defined

CPLAT_End_Namespace_CPLAT

#endif

#endif	// _H_CP_DT_WinObjects
