/*
=========================================================================

	FILE:		CP_LineSeparatorParser.h
	
				Copyright  2003. Ken Stahlman. All Rights Reserved.
	
	PURPOSE:	A class to parse a memory block and break each line into
				a string that is stored in a list. Use for getting lines from
				blocks that are separated by lines, or tabs.
	
	HISTORY:	1st Version - May 2003.
	
	NOTES:		- none -

	VERSION:	Current Revision: $Revision: 106 $
				Latest Checkout:  $Date: 2005-03-21 15:03:06 -0800 (Mon, 21 Mar 2005) $

=========================================================================
*/
#ifndef _H_CP_LineSeparatorParser
#define _H_CP_LineSeparatorParser
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_HandleBlock.h"
#include "CP_String.h"
#include "CP_Types.h"

	// Standard Library
#include <vector>

CPLAT_Begin_Namespace_CPLAT

#if ! TARGET_OS_LINUX
	typedef std::vector<CP_String, std::allocator<CP_String> >						CP_Lines_Array;
	typedef std::vector<CP_String, std::allocator<CP_String> >::iterator			CP_Lines_Iterator;
	typedef std::vector<CP_String, std::allocator<CP_String> >::reverse_iterator	CP_Lines_ReverseIterator;
#else
	typedef std::vector<CP_String >													CP_Lines_Array;
	typedef std::vector<CP_String >::iterator										CP_Lines_Iterator;
	typedef std::vector<CP_String >::reverse_iterator								CP_Lines_ReverseIterator;
#endif

enum
{
	kCP_LineSeparator_LineEnding,
	kCP_LineSeparator_Tabs,
	kCP_LineSeparator_Commas
};

//!  CP_LineSeparatorParser
/*!
  A class to parse a memory block and break each line into a string that is
  stored in a list. Use for getting lines from blocks that are separated by lines, or tabs. 
*/
class CP_EXPORT CP_LineSeparatorParser
{
public:
												// Construction / Destruction
										CP_LineSeparatorParser();
	virtual								~CP_LineSeparatorParser();
	
			UInt32						Parse(
												const CP_HandleBlock *inData,
												SInt16 inLineSeparator,
												bool inClearList );
	
			CP_Lines_Array				*GetLinesArray()								{ return( fLines ); }

	// class data
protected:
	CP_Lines_Array						*fLines;
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_LineSeparatorParser




