//=========================================================================
//
//	FILE:				CP_M_DragTarget.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Class used in drag and drop to provide a drag target.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 247 $
//						Latest Checkout:  $Date: 2005-07-30 19:06:38 -0700 (Sat, 30 Jul 2005) $
//
//=========================================================================
#ifndef _H_CP_M_DragTarget
#define _H_CP_M_DragTarget
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_DragDrop.h"
#include "CP_Region.h"

	// Standard Library
#include <list>

CPLAT_Begin_Namespace_CPLAT

	// forward class declaration
class CP_M_DragTarget;
class CP_Window;

#if TARGET_OS_WIN32
	class CP_EXPORT CDropTarget;
#endif

struct CP_S_DragTarget
{
	CP_M_DragTarget				*fDropTarget;
	CP_Window					*fWindow;
	
										CP_S_DragTarget();
										CP_S_DragTarget(
												CP_M_DragTarget *inDropTarget,
												CP_Window *inOSWindow );
										CP_S_DragTarget( const CP_S_DragTarget& inDragTarget );

			CP_S_DragTarget&			operator =( const CP_S_DragTarget& inDragTarget );
			bool						operator ==( const CP_S_DragTarget& inDragTarget ) const;
			bool						operator !=( const CP_S_DragTarget& inDragTarget ) const;
};

#ifndef TARGET_OS_LINUX
	typedef std::list<CP_S_DragTarget, std::allocator<CP_S_DragTarget> >					CP_DragTarget_List;
	typedef std::list<CP_S_DragTarget, std::allocator<CP_S_DragTarget> >::iterator			CP_DragTarget_Iterator;
	typedef std::list<CP_S_DragTarget, std::allocator<CP_S_DragTarget> >::reverse_iterator	CP_DragTarget_ReverseIterator;
#else
	typedef std::list<CP_S_DragTarget>														CP_DragTarget_List;
	typedef std::list<CP_S_DragTarget>::iterator											CP_DragTarget_Iterator;
	typedef std::list<CP_S_DragTarget>::reverse_iterator									CP_DragTarget_ReverseIterator;
#endif

/*!
*	@class		CP_M_DragTarget
*	@brief		Class used in drag and drop to provide a drag target.
*/
class CP_EXPORT CP_M_DragTarget
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_M_DragTarget();
	//! Destructor.
	virtual								~CP_M_DragTarget() throw();
	//@}

	//! @name Drag Target List
	//@{
			void						AddDragTarget(
												CP_M_DragTarget *inDragTarget,
												CP_Window *inWindow );
			void						RemoveDragTarget(
												CP_M_DragTarget *inDragTarget,
												CP_Window *inWindow );
	//@}

	virtual	void						HandleDragReceive( CP_DragDrop& /*inDragDrop*/ )	{}

	// class data
protected:									
	static CP_DragTarget_List			*fsDragTargetList;
	static CP_M_DragTarget				*fsCurrentDragTarget;
	static bool							fsDragHasLeftSender;
	
	CP_Window 							*fWindow;
	bool								fDropAreaIsHilited;
	bool								fCanAcceptCurrentDrag;
	
#if TARGET_OS_WIN32
	OSWindow							fTargetWindow;		/*! Windows HWND for the target. */
	CDropTarget							*fDropTarget;		/*! OLE drop target interface object. */
	CP_Point							fDropPoint;			/*! Screen location where drop occurred. */
#endif

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
public:
	//! @name Drag Target
	//@{
			bool						CanAcceptDrag( CP_DragDrop& inDragDrop );

	virtual	void						HiliteDropArea( CP_DragDrop& inDragDrop );
	virtual	void						UnhiliteDropArea( CP_DragDrop& inDragDrop );
	//@}

protected:
	//! @name Drag Manager callbacks
	//@{
	static pascal OSErr					HandleDragTrackingCallback(
												DragTrackingMessage inMessage,
												WindowPtr inOSWindow,
												void *inRefCon,
												DragReference inDragRef );

	static pascal OSErr					HandleDragReceiveCallback(
												WindowPtr inOSWindow,
												void *inRefCon,
												DragReference inDragRef );
	//@}

	//! @name Drag Target
	//@{
	static	CP_M_DragTarget 			*FindDragTarget(
												OSWindow inOSWindow,
												CP_Point& inMouseLocation,
												CP_DragDrop& inDragDrop );

	virtual	void						OnDragEnter(
												CP_DragDrop& inDragDrop,
												bool inDragHasLeftSender );
	virtual	void						OnDragLeave( CP_DragDrop& inDragDrop );
	virtual	void						OnDragTrack( CP_DragDrop& inDragDrop );
	//@}

	virtual bool						OnCanAcceptDrag(
												UInt32 inItem,
												CP_DragDrop& inDragDrop ) = 0;
	virtual CP_Region 					GetDropRegion() = 0;

	virtual	bool						PtInDropArea( CP_Point& inGlobalPoint );

	//! @name Tracking
	//@{
	static void							HandleTrackInWindow(
												WindowPtr inOSWindow,
												CP_DragDrop& inDragDrop );
	//@}
#endif

#if TARGET_OS_WIN32
public:
			void						SetTargetWindow( OSWindow inWindow );

	virtual	void						OnDragEnter(
												LPDATAOBJECT pIDataSource,
												DWORD grfKeyState,
												POINTL pt,
												LPDWORD pdwEffect );
	virtual	void						OnDragOver(
												DWORD grfKeyState,
												POINTL pt,
												LPDWORD pdwEffect );
	virtual	void						OnDragLeave();

	virtual	void						OnDrop(
												LPDATAOBJECT pIDataSource,
												DWORD grfKeyState, 
												POINTL pt,
												LPDWORD pdwEffect );
												
			CP_Point					GetDropPoint()											{ return( fDropPoint ); }

protected:
	virtual	bool						OnCanAcceptDragWin(
												LPDATAOBJECT pIDataSource,
												DWORD grfKeyState,
												POINTL pt,
												LPDWORD pdwEffect );
#endif

#if TARGET_OS_LINUX
#endif
};

#if TARGET_OS_MAC

class CP_DragTrackingUPP
{
public:
										CP_DragTrackingUPP(
												DragTrackingHandlerProcPtr inProcPtr,
												OSWindow inWindow,
												void *inRefCon = NULL );
			
										~CP_DragTrackingUPP();
			
			operator 					DragTrackingHandlerUPP()							{ return( fTrackingUPP ); }
			
protected:
	DragTrackingHandlerUPP				fTrackingUPP;
	OSWindow							fOSWindow;
};


class CP_DragReceiveUPP
{
public:
										CP_DragReceiveUPP(
												DragReceiveHandlerProcPtr inProcPtr,
												OSWindow inWindow,
												void *inRefCon = NULL );
					
										~CP_DragReceiveUPP();
			
			operator					DragReceiveHandlerUPP()								{ return( fReceiveUPP ); }
			
protected:
	DragReceiveHandlerUPP				fReceiveUPP;
	OSWindow							fOSWindow;
};
#endif

#if TARGET_OS_WIN32

class CP_EXPORT CDropTarget : public IDropTarget
{
protected:
									/*! Reference count of this object. */
		UInt32               		fRefCount; 
									/*! Data source object */
        LPDATAOBJECT				fpIDataSource;
									/*! Pointer to the CP_M_DragTarget object. */
		CP_M_DragTarget				*fCPDragTargetObject;
	      
public:
        						CDropTarget( CP_M_DragTarget *inCPDragTargetObject );
        						~CDropTarget();

		void					SetDataSource( LPDATAOBJECT inDataSource );
								/*! Return the data source object. */
		LPDATAOBJECT			GetDataSource()									{ return( fpIDataSource ); }

        	// IDropTarget interface members
        STDMETHODIMP			QueryInterface(REFIID, LPVOID FAR *);
        STDMETHODIMP_(UInt32)	AddRef(void);
        STDMETHODIMP_(UInt32)	Release(void);

        STDMETHODIMP 			DragEnter(LPDATAOBJECT, DWORD, POINTL, LPDWORD);
        STDMETHODIMP 			DragOver(DWORD, POINTL, LPDWORD);
        STDMETHODIMP 			DragLeave(void);
        STDMETHODIMP 			Drop(LPDATAOBJECT, DWORD, POINTL, LPDWORD);    
};

#endif	// TARGET_OS_WIN32

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_M_DragTarget

