//=========================================================================
//
//	FILE:				CP_Menu.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Class to represent a platforms menu.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 268 $
//						Latest Checkout:  $Date: 2005-08-31 22:38:24 -0700 (Wed, 31 Aug 2005) $
//
//=========================================================================
#ifndef _H_CP_Menu
#define _H_CP_Menu
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Menu_Imp_Mac.h"
#include "CP_Menu_Imp_Win.h"
#include "CP_M_ReferenceCounted.h"
#include "CP_String.h"

#if TARGET_OS_LINUX
	#include "CP_Menu_Imp_Gtk.h"
#endif

	// Standard Library
#include <vector>

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class	CP_Menu
*	@brief	A class for representing a platforms menu object.
*	
*	This class is implemented for each of the supported platforms through a
*	CP_Menu_Imp class.
*
*	The menu class is also reference counted in case the menu is used in more
* 	than one place, and the underlying OS shares a copy of the native menu.
*/
class CP_EXPORT CP_Menu : public CP_Menu_Imp, public CP_M_RefCounted
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Menu();
										CP_Menu(
												SInt16 inMenuID,
												const CP_String& inMenuTitle,
												bool inPopup = false );
										CP_Menu( const CP_String& inMenuTitle );
										CP_Menu(
												SInt16 inMenuID,
												const CP_String& inMenuTitle,
												OSMenu inOSMenu );
	//! Destructor.
	virtual								~CP_Menu() throw();
	//@}
			
protected:

	// class data
protected:
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Menu( OSMenu innMenu );
	//@}
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_Menu

