//=========================================================================
//
//	FILE:				CP_SocketOutStream.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Class to read stream data from socket connection.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 106 $
//						Latest Checkout:  $Date: 2005-03-21 15:03:06 -0800 (Mon, 21 Mar 2005) $
//
//=========================================================================
#ifndef _H_CP_SocketInStream
#define _H_CP_SocketInStream
#ifndef __BUILD_LINUX__
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_InStream.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_SocketInStream
*	@brief		Class to read stream data from socket connection.
*/
class CP_EXPORT CP_SocketInStream : public CP_InStream
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_SocketInStream(
												class CP_Socket& inSocket,
												bool inHasHeader = true );
	//! Destructor.
	virtual								~CP_SocketInStream () throw();
	//@}

	//! @name Testing
	//@{
	virtual bool						IsEOF() const;
	//@}

	//! @name Utility
	//@{
	virtual void						Close();
	//@}
	
protected:
	class CP_Socket& fSocket;

	virtual UInt32 OnReadBytes(void *inDestBuffer,UInt32 inNumberBytes );
	
private:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_SocketInStream();
										CP_SocketInStream( const CP_SocketInStream& ob );
	//@}

	//! @name operators
	//@{
	CP_SocketInStream&					operator = ( const CP_SocketInStream& obj);
	//@}
	
	// Make private, because GetLength, GetPosition and SetPosition should not be called on a socket stream.
	//! @name Getters
	//@{
	virtual UInt32						GetLength() const;
	virtual UInt32						GetPosition() const;
	//@}

	//! @name Setters
	//@{
	virtual void						SetPosition( UInt32 inPosition );
	//@}
	
	// class data
private:
	bool								fIsAtEOF;		/*! Flag to indicate if we are at the EOF marker. */

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_SocketInStream
