//=========================================================================
//
//	FILE:				CP_ScriptableObject_Prop.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			A CP_ScriptableObject_Imp class to handle properties of objects.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 10 $
//						Latest Checkout:  $Date: 2004-12-24 14:46:10 -0800 (Fri, 24 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_ScriptableObject_Property
#define _H_CP_ScriptableObject_Property
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_MAC

	// CPLAT_Framework
//#include "AppleEvent.h"
#include "CP_ScriptableObject_Imp_AE.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_ScriptableObject_Property
*	@brief		A CP_ScriptableObject_Imp class to handle properties of objects.
*
*	@ingroup	AppleEvents
*/
class CP_EXPORT CP_ScriptableObject_Property : public CP_ScriptableObject_Imp
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_ScriptableObject_Property(
												CP_ScriptableObject_Imp *inContainer,
												const DescType inPropertyType );
	//! Destructor.
	virtual								~CP_ScriptableObject_Property() throw();
	//@}

	//! @name Getters
	//@{
	virtual DescType					GetAppleClass() const;
	virtual	DescType					GetPropertyType() const										{ return( fPropertyType ); }
	//@}

	//! @name Events
	//@{
											// Main AppleEvent handling routine, subclasses need
											// to override and implement this method
	virtual	void						HandleAppleEventSelf(
												const AppleEvent& inEvent,
												AppleEvent& inOutReply,
												SInt32 inRefCon );
	//@}

	//! @name Data
	//@{
	virtual void						DoGetData(
												const AppleEvent& inEvent,
												AppleEvent& inOutReply );
	virtual void 						DoSetData(
												const AppleEvent& inEvent,
												AppleEvent& inOutReply );

	virtual	void						SendAE_SetData(
												const DescType inDataType,
												Ptr inDataPtr,
												Size inDataSize,
												bool inDoExecute );
	//@}

protected:
	//! @name Specifier
	//@{
	virtual	void						MakeSelfSpecifier(
												AEDesc& inContainerSpec,
												AEDesc& inOutSelfSpec );
	//@}

	// class data members
protected:
	DescType							fAppleClassType;	/* ! AppleEvent class type. */
	DescType							fPropertyType;		/* ! Property type. */
};

CPLAT_End_Namespace_CPLAT

#endif

#endif	// _H_CP_ScriptableObject_Property
