//=========================================================================
//
//	FILE:				CP_ChasingArrows.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Implementation of a platforms chasing arrows control.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_ChasingArrows
#define _H_CP_ChasingArrows
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_ImageList.h"
#include "CP_PlatformControl.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_ChasingArrows
*	@brief		Implementation of a platforms chasing arrows control.
*
*	@section 	persistance Persistance:
*				The following tags are implemented to create the button from
*				a persistance stream:
*					- kCP_Persist_ControlSignature - UInt32
*					- kCP_Persist_Bounds - CP_Rect
*					- kCP_Persist_IsHidden - bool
*					- kCP_Persist_IsEnabled - bool
*
*	@section 	signals Signals and Slots:
*				The following signals and slot are implemented in this class:
*					- None
*
*				From CP_PlatformControl:
*					- kCP_Signal_Clicked
*					- kCP_Signal_ValueChanged
*
*	@ingroup	UI
*/
class CP_EXPORT CP_ChasingArrows : public CP_PlatformControl
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_ChasingArrows();
										CP_ChasingArrows(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//! Destructor.
	virtual								~CP_ChasingArrows() throw();
	//@}
			
	//! @name Persistance
	//@{
	static CP_M_Persist					*PersistCreator();
	//@}
			
protected:
	//! @name Events
	//@{
	virtual	void						InitEventHandler( CP_EventHandler& inEventHandler );
	//@}

	//! @name Persistance
	//@{
	virtual	void						OnInitPersist(
												CP_View *inSuperview,
												CP_DataValueList& inDataValueList );
	//@}

	// class data
protected:

	#if TARGET_OS_WIN32 || TARGET_OS_LINUX
		CP_ImageList					*fArrowImages; 

		UInt16							fWinTimer;
		SInt16							fCurrentFrame;
	#endif
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//@}
#endif

#if TARGET_OS_WIN32
protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

private:
	//! @name Events
	//@{
			void						HandleTimer( CP_Event_Base& inEvent );
	//@}

	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//@}
#endif

#if TARGET_OS_LINUX
protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//@}
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_ChasingArrows
