//=========================================================================
//
//	FILE:				CP_RadioButton.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Implementation of a platforms Radio Button control.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_RadioButton
#define _H_CP_RadioButton
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_PlatformControl.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_RadioButton
*	@brief		Implementation of a platforms Radio Button control.
*
*	@ingroup	UI
*/
class CP_EXPORT CP_RadioButton : public CP_PlatformControl
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_RadioButton();
										CP_RadioButton(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle,
												UInt32 inCommand,
												SInt32 inInitialValue = 0,
												bool inAutoToggle = true );
	//! Destructor.
	virtual								~CP_RadioButton() throw();
	//@}
			
	//! @name Persistance
	//@{
	static CP_M_Persist					*PersistCreator();
	//@}
			
protected:
	//! @name Persistance
	//@{
	virtual	void						OnInitPersist(
												CP_View *inSuperview,
												CP_DataValueList& inDataValueList );
	//@}

	// class data
protected:
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle,
												UInt32 inCommand,
												SInt32 inInitialValue = 0,
												bool inAutoToggle = true );
	//@}
#endif

#if TARGET_OS_WIN32
public:
	//! @name Slots
	//@{
	virtual	void						HandleCommandProcess( CP_Event_Base& inEvent );
	//@}

	//! @name Value
	//@{
	virtual	void						SetValue( SInt32 inValue );
	//@}

private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle,
												UInt32 inCommand,
												SInt32 inInitialValue = 0,
												bool inAutoToggle = true );
	//@}
#endif

#if TARGET_OS_LINUX
private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle,
												UInt32 inCommand,
												SInt32 inInitialValue = 0,
												bool inAutoToggle = true );
	//@}
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_RadioButton
