//=========================================================================
//
//	FILE:				CP_Relevance.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Implementation of a platforms relevance control.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_Relevance
#define _H_CP_Relevance
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_PlatformControl.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_Relevance
*	@brief		Implementation of a platforms relevance control.
*
*	@ingroup	UI
*/
class CP_EXPORT CP_Relevance : public CP_PlatformControl
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Relevance();
								CP_Relevance(
										CP_View *inSuperview,
										const CP_Point& inUpperLeft,
										const CP_Size& inContentSize,
										SInt32 inValue,
										SInt32 inMinimum,
										SInt32 inMaximum );
	//! Destructor.
	virtual						~CP_Relevance() throw();
	//@}
			
	//! @name Persistance
	//@{
	static CP_M_Persist			*PersistCreator();
	//@}
			
protected:
	//! @name Persistance
	//@{
	virtual	void				OnInitPersist(
										CP_View *inSuperview,
										CP_DataValueList& inDataValueList );
	//@}

	// class data
protected:
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
protected:
	//! @name Drawing
	//@{
	virtual	void				OnDraw(
										CP_Canvas& inCanvas,
										CP_Region& inUpdateArea );
	//@}

private:
	//! @name Initialization
	//@{
			void				CreatePlatformImp(
										CP_View *inSuperview,
										const CP_Point& inUpperLeft,
										const CP_Size& inContentSize,
										SInt32 inValue,
										SInt32 inMinimum,
										SInt32 inMaximum );
	//@}
#endif

#if TARGET_OS_WIN32
protected:
	//! @name Drawing
	//@{
	virtual	void				OnDraw(
										CP_Canvas& inCanvas,
										CP_Region& inUpdateArea );
	//@}

private:
	//! @name Initialization
	//@{
			void				CreatePlatformImp(
										CP_View *inSuperview,
										const CP_Point& inUpperLeft,
										const CP_Size& inContentSize,
										SInt32 inValue,
										SInt32 inMinimum,
										SInt32 inMaximum );
	//@}
#endif

#if TARGET_OS_LINUX
protected:
	//! @name Drawing
	//@{
	virtual	void				OnDraw(
										CP_Canvas& inCanvas,
										CP_Region& inUpdateArea );
	//@}

private:
	//! @name Initialization
	//@{
			void				CreatePlatformImp(
										CP_View *inSuperview,
										const CP_Point& inUpperLeft,
										const CP_Size& inContentSize,
										SInt32 inValue,
										SInt32 inMinimum,
										SInt32 inMaximum );
	//@}
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_Relevance
