//=========================================================================
//
//	FILE:				CP_SearchField.h
//	
//						Copyright  2005. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Implementation of the HIViewSearchField
//	
//	HISTORY:			1st Version - February 2005.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 94 $
//						Latest Checkout:  $Date: 2005-02-20 20:03:45 -0800 (Sun, 20 Feb 2005) $
//
//=========================================================================
#ifndef _H_CP_SearchField
#define _H_CP_SearchField
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_PlatformControl.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_SearchField
*	@brief		Implementation of an HISearchField
*
*	@ingroup	UI
*/
class CP_EXPORT CP_SearchField : public CP_PlatformControl
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_SearchField();
										CP_SearchField(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//! Destructor.
	virtual								~CP_SearchField() throw();
	//@}
			
	//! @name Persistance
	//@{
	static CP_M_Persist					*PersistCreator();
	//@}
			
protected:
	//! @name Events
	//@{
	virtual	void						InitEventHandler( CP_EventHandler& inEventHandler );
	//@}

	//! @name Persistance
	//@{
	virtual	void						OnInitPersist(
												CP_View *inSuperview,
												CP_DataValueList& inDataValueList );
	//@}

private:
	//! @name Signal / Slots
	//@{
			void						HandleTextAccepted( CP_Event_Base& inEvent );
	//@}

	// class data
protected:
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//@}
#endif

#if TARGET_OS_WIN32
protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//@}
#endif

#if TARGET_OS_LINUX
protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//@}
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_SearchField
