//=========================================================================
//
//	FILE:				CP_StaticText.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			CP_PlatformControl subclass to display static text.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 152 $
//						Latest Checkout:  $Date: 2005-04-15 21:49:17 -0700 (Fri, 15 Apr 2005) $
//
//=========================================================================
#ifndef _H_CP_StaticText
#define _H_CP_StaticText
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_PlatformControl.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_StaticText
*	@brief		Implementation of a pane to display static text.
*
*	@ingroup	UI
*/
class CP_EXPORT CP_StaticText : public CP_PlatformControl
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_StaticText();
										CP_StaticText(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle );
	//! Destructor.
	virtual								~CP_StaticText() throw();
	//@}

	//! @name Getters
	//@{
	virtual	SInt16						GetTextHeight();
	//@}

	//! @name Persistance
	//@{
	static CP_M_Persist					*PersistCreator();
	//@}

	//! @name Setters
	//@{
	virtual	void						SetTitle( const CP_String& inText );
	virtual	void						SetFontSpec( CP_FontSpec& inFontSpec );
	//@}

	//! @name Setters
	//@{
	virtual	void						SetValue( SInt32 inValue );
	//@}

protected:
	//! @name Persistance
	//@{
	virtual	void						OnInitPersist(
												CP_View *inSuperview,
												CP_DataValueList& inDataValueList );
	//@}

	// class data
protected:
	
	#if TARGET_OS_WIN32
		CP_String						fText;
		
		CP_FontSpec						fFontSpec;
		bool							fHasValidFontSpec;
	#endif
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle );
	//@}
#endif

#if TARGET_OS_WIN32
protected:
	virtual	void						OnDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );

private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle );
	//@}
#endif

#if TARGET_OS_LINUX
private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle );
	//@}
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_StaticText

