//=========================================================================
//
//	FILE:				CP_TableGeometry_Mixed.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			CP_TableGeometry_Base class for maining multi value
//						geometry for a table. Multi value geometry means that
//						rows and columns can be different sizes.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 110 $
//						Latest Checkout:  $Date: 2005-03-23 14:37:56 -0800 (Wed, 23 Mar 2005) $
//
//=========================================================================
#ifndef _H_CP_TableGeometry_Mixed
#define _H_CP_TableGeometry_Mixed
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_TableGeometry_Base.h"
#include "CP_TableGeometry_Multi.h"

	// Standard Library
#include <vector>

CPLAT_Begin_Namespace_CPLAT

	// forward declarations
class CP_TableView;

	// structure to maintain information on the properties of our DataBrowser.
struct CP_S_TableGeometryMixed_Row
{
	SInt32					fRowHeight;
	CP_Dimension_Array		fColWidths;
	
							CP_S_TableGeometryMixed_Row();
							CP_S_TableGeometryMixed_Row(
									SInt32 inRowHeight,
									SInt32 inNumberCols,
									SInt32 inColumnWidth );
							CP_S_TableGeometryMixed_Row( const CP_S_TableGeometryMixed_Row& inRowGeometry );

	CP_S_TableGeometryMixed_Row&	operator =( const CP_S_TableGeometryMixed_Row& iinRowGeometry );
};

#if TARGET_OS_LINUX
	typedef std::vector<CP_S_TableGeometryMixed_Row, std::allocator<CP_S_TableGeometryMixed_Row> >						CP_RowDimension_Array;
	typedef std::vector<CP_S_TableGeometryMixed_Row, std::allocator<CP_S_TableGeometryMixed_Row> >::iterator			CP_RowDimension_Iterator;
	typedef std::vector<CP_S_TableGeometryMixed_Row, std::allocator<CP_S_TableGeometryMixed_Row> >::reverse_iterator	CP_RowDimension_ReverseIterator;
#else
	typedef std::vector<CP_S_TableGeometryMixed_Row>																	CP_RowDimension_Array;
	typedef std::vector<CP_S_TableGeometryMixed_Row>::iterator															CP_RowDimension_Iterator;
	typedef std::vector<CP_S_TableGeometryMixed_Row>::reverse_iterator													CP_RowDimension_ReverseIterator;
#endif

/*!
*	\class		CP_TableGeometry_Mixed
*	\brief		CP_TableGeometry_Base class for maining multi value geometry for a table.
*				Multi value geometry means that rows and columns can be different sizes.
*/
class CP_EXPORT CP_TableGeometry_Mixed : public CP_TableGeometry_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_TableGeometry_Mixed( CP_TableView *inTableView );
	//! Destructor.
	virtual								~CP_TableGeometry_Mixed() throw();
	//@}
		
	//! @name Columns
	//@{
	virtual	SInt32						GetNumberColumns( SInt32 inRow );
	virtual void						SetNumberColumns(
												SInt32 inRow,
												SInt32 inNumberColumns );

	virtual SInt32						GetColumnWidth(
												SInt32 inRow,
												SInt32 inColumn );
	virtual void						SetColumnWidth(
												SInt32 inRow,
												SInt32 inColumn,
												SInt32 inColumnWidth );

	virtual	CP_Rect						GetColumnBounds(
												const CP_Rect& inRowBounds,
												SInt32 inRow,
												SInt32 inColumn );
	virtual	CP_Rect						GetColumnBounds(
												SInt32 inRow,
												SInt32 inColumn );
	//@}

	//! @name Rows
	//@{
	virtual SInt32						GetNumberRows();
	virtual void						SetNumberRows( SInt32 inNumberRows );

	virtual SInt32						GetRowHeight( SInt32 inRow );
	virtual void						SetRowHeight(
												SInt32 inRow,
												SInt32 inRowHeight );

	virtual	CP_Point					GetRowLocation( SInt32 inRow );

			void						AddRow();
	//@}

	//! @name Testers
	//@{
	virtual	SInt32						GetRowHitBy( const CP_Point& inHitPoint );
	virtual	SInt32						GetColumnHitBy( const CP_Point& inHitPoint );
	//@}

protected:

	// class data
protected:
	CP_RowDimension_Array				fRowDimensions;
	SInt32								fDefaultRowHeight;
	SInt32								fDefaultColWidth;
	SInt32								fDefaultNumberCols;
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_TableGeometry_Mixed

