//=========================================================================
//
//	FILE:				CP_HPEN.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			A class to manage a Windows HPEN.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_HPEN
#define _H_CP_HPEN
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_WIN32

	// CPLAT_Framework
#include "CP_Canvas.h"
#include "CP_Types.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_HPEN
*	@brief		Class that provides a wrapper for the Windows HPEN.
*/
class CP_EXPORT CP_HPEN
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_HPEN();
										CP_HPEN( HPEN inHPEN );
										CP_HPEN( const CP_HPEN& inHPEN );
	//! Destructor.
	virtual								~CP_HPEN() throw();
	//@}
			
	//! @name Canvas
	//@{
			void						UseInCanvas( CP_Canvas& inCanvas );
			void						ResetCanvas();

										/*!
										*	Sets the canvas that this pen is used with.
										*
										*	@param		inCanvas		The CP_Canvas object the pen is used with.
										*
										*	@exception	none
										*	
										*	@return		void
										*/
			void						SetCanvas( CP_Canvas& inCanvas )			{ fCanvas = inCanvas; }
	//@}

	//! @name Getters
	//@{
										/*!
										*	Returns the Windows HPEN associated with this class.
										*
										*	@exception	none
										*	
										*	@return		HPEN	The Windows HPEN associated with this object.
										*/
			HPEN						GetHPEN()									{ return( fHPEN ); }

										/*!
										*	Returns the stroke size that the pen draws in.
										*
										*	@exception	none
										*	
										*	@return		UInt16	The size of the pens stroke when drawing.
										*/
			UInt16						Size()										{ return( fSize ); }

										/*!
										*	Returns the color that the pen draws in.
										*
										*	@exception	none
										*	
										*	@return		CP_RGBColor	The color of the pen when drawing.
										*/
			CP_RGBColor					GetColor() const							{ return( fColor ); }
	//@}

	//! @name operators
	//@{
			CP_HPEN&					operator =( const CP_HPEN& inHPEN );
	//@}
										
	//! @name Save / Restore
	//@{
			void						Save();
			void						Restore();
	//@}

	//! @name Setters
	//@{
			void						SetSize( const USHORT inSize );
			void						SetColor( const CP_RGBColor& inColor );
	//@}

protected:
	//! @name Misc
	//@{
			void						UpdatePen();
	//@}

	// class data
protected:
	CP_Canvas							fCanvas;			/*! CP_Canvas object the pen is used in. */
	
	HPEN								fHPEN;				/*! The HPEN we manage. */

	CP_RGBColor							fColor;				/*! Color of our pen stroke (foreground) */
	UInt16								fSize;				/*! Size of the pen stroke. */
	SInt16								fPenStyle;			/*! Style of the pens stroke. */

	HPEN								fSavedPen;			/*! Saved HPEN, used when restoring. */
	SInt16								fSavedDCInstance;	/*! Saved HDC, used when restoring. */
};

CPLAT_End_Namespace_CPLAT

#endif  // TARGET_OS_WIN32

#endif	// _H_CP_HPEN

